@@ -30,7 +30,7 @@ Implementation Notes
 
 import time
 import struct
-import adafruit_bus_device.i2c_device as i2c_device
+from adafruit_bus_device import i2c_device
 from micropython import const
 
 __version__ = "0.0.0-auto.0"
